==> question2answer-1.0-language-pt-BR.zip: pt/qa-lang-main.php <==
<?php
	
/*
	Question2Answer 1.0 (c) 2010, Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-main.php
	Version: 1.0
	Date: 2010-04-09 16:07:28 GMT
	Description: Language phrases commonly used throughout Q2A, plus a few other misc ones
  Language: Português - Brasil
  Author: André Ortega - www.brainwork.com.br/qa

	This software is licensed for use in websites which are connected to the
	public world wide web and which offer unrestricted access worldwide. It
	may also be freely modified for use on such websites, so long as a
	link to http://www.question2answer.org/ is displayed on each page.


	THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
	INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
	AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
	THE COPYRIGHT HOLDER BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
	SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
	TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
	PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
	LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
	NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

	return array(
		'1_answer' => '1 resposta',
		'1_day' => '1 dia',
		'1_disliked' => '1 contra',
		'1_hour' => '1 hora',
		'1_liked' => '1 a favor',
		'1_minute' => '1 minuto',
		'1_month' => '1 mês',
		'1_point' => '1 ponto',
		'1_question' => '1 pergunta',
		'1_second' => '1 segundo',
		'1_vote' => '1 voto',
		'1_week' => '1 semana',
		'1_year' => '1 ano',
		'anonymous' => 'anônimo',
		'answer_limit' => 'Muita respostas recebidas - Por favor tente novamente mais tarde',
		'answered_x_ago' => 'respondida ^ atrás',
		'ask_limit' => 'Muitas perguntas recebidas - Por favor tente novamente mais tarde',
		'asked_x_ago' => 'perguntado ^ atrás',
		'by_x' => 'Por ^',
		'captcha_error' => 'Por favor complete a verificação anti-spam',
		'captcha_label' => 'Verificação Anti-spam:',
		'comment_limit' => 'Muitos comentários respondidos - Por favor tente novamente mais tarde',
		'commented_x_ago' => 'comentado ^ atrás',
		'feedback_email' => 'Seu email: (opcional)',
		'feedback_empty' => 'Por favor use este campo para enviar comentários e/ou sugestões',
		'feedback_message' => 'Seu comentário e/ou sugestão para ^:',
		'feedback_name' => 'Seu nome: (opcional)',
		'feedback_sent' => 'Sua mensagem foi enviada - Obrigado.',
		'feedback_title' => 'Mande sua opinição',
		'general_error' => 'Ocorreu um erro no servidor - Por favor tente novamente.',
		'highest_users' => 'Usuários com mais pontos',
		'logged_in_x' => 'Olá ^',
		'max_length_x' => 'Tamanho máximo de ^ caracteres',
		'me' => 'eu',
		'min_length_x' => 'Por favor forneça mais informação (pelo menos ^ caracteres)',
		'nav_account' => 'Minha conta',
		'nav_admin' => 'Admin',
		'nav_ask' => 'Faça uma pergunta',
		'nav_feedback' => 'Envie sua opinião',
		'nav_login' => 'Login',
		'nav_logout' => 'Logout',
		'nav_qs' => 'Perguntas',
		'nav_register' => 'Registro',
		'nav_tags' => 'Tags',
		'nav_unanswered' => 'Sem respostas',
		'nav_users' => 'Usuários',
		'no_active_users' => 'Não foram encontrados usuários ativos',
		'no_answers_found' => 'Não foram encontradas respostas',
		'no_comments_found' => 'Não foram encontrados comentários',
		'no_questions_found' => 'Não foram encontradas perguntas',
		'no_related_qs_title' => 'Nenhuma questão relacionada',
		'no_results_for_x' => 'Nenhum resultado encontrado ^',
		'no_tags_found' => 'Nenhuma tag encontrada',
		'no_una_questions_found' => 'Não foi encontrada nenhuma pergunta sem resposta',
		'page_label' => 'Página:',
		'page_next' => 'npróxima',
		'page_not_found' => 'Página não encontrada',
		'page_prev' => 'prev',
		'popular_tags' => 'Tags mais populares',
		'questions_tagged_x' => 'Perguntas recentes tagged ^',
		'recent_as_title' => 'Perguntas respondidas recentemente',
		'recent_cs_title' => 'Comentários adicionados recentemente',
		'recent_qs_as_title' => 'Perguntas e respostas rececentes',
		'recent_qs_title' => 'Perguntas recentes',
		'related_qs_title' => 'Perguntas relacionadas',
		'results_for_x' => 'Resultada da busca ^',
		'search_button' => 'Busca',
		'search_title' => 'Procurar perguntas',
		'send_button' => 'Enviar',
		'suggest_ask' => 'Participe ^1fazendo uma pergunta^2.',
		'suggest_qs_tags' => 'Para ver mais clique na ^1lista completa de questões^2 ou ^3nas tags populares^4.',
		'unanswered_qs_title' => 'Perguntas recentes sem respostas',
		'vote_disabled_hidden_a' => 'Você nãopode votar em respostas ocultas',
		'vote_disabled_hidden_q' => 'Você não pode votar em perguntas ocultas',
		'vote_disabled_my_a' => 'Você não pode votar em suas próprias respostas',
		'vote_disabled_my_q' => 'Você não pode votar em suas próprias perguntas',
		'vote_down_popup' => 'Clique para votar contra',
		'vote_limit' => 'Muitos votos recebidos - Por favor tente mais tarde',
		'vote_must_login' => 'Por favor ^1faça o login^2 ou ^3registre-se^4 para votar.',
		'vote_not_allowed' => 'Não é permitido votar nisto',
		'vote_up_popup' => 'Clique para votar',
		'voted_down_popup' => 'Você votou contra - clique para remover o voto',
		'voted_up_popup' => 'Você votou a favor - clique para remover o voto',
		'x_ago' => '^ atrás',
		'x_answers' => '^ respostas',
		'x_days' => '^ dias',
		'x_disliked' => '^ contra',
		'x_hours' => '^ horas',
		'x_liked' => '^ a favor',
		'x_minutes' => '^ minutos',
		'x_months' => '^ meses',
		'x_points' => '^ pontos',
		'x_questions' => '^ questões',
		'x_seconds' => '^ segundos',
		'x_votes' => '^ votos',
		'x_weeks' => '^ semanas',
		'x_years' => '^ anos',
	);
	
?>

==> question2answer-1.2-language-pt-BR.zip: pt/qa-lang-main.php <==
<?php
	
/*
	Question2Answer 1.2 (c) 2010, Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-main.php
  Version: 1.2
	Date: 2010-07-20 09:24:45 GMT
	Description: Language phrases commonly used throughout Q2A, plus a few other misc ones
	Language: Português - Brasil
  Author: André Ortega - www.brainwork.com.br/qa


	This software is free to use and modify for public websites, so long as a
	link to http://www.question2answer.org/ is displayed on each page. It may
	not be redistributed or resold, nor may any works derived from it.
	
	More about this license: http://www.question2answer.org/license.php


	THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
	INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
	AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
	THE COPYRIGHT HOLDER BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
	SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
	TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
	PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
	LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
	NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

	return array(
		'1_answer' => '1 resposta',
		'1_day' => '1 dia',
		'1_disliked' => '1 contra',
		'1_hour' => '1 hora',
		'1_liked' => '1 a favor',
		'1_minute' => '1 minuto',
		'1_month' => '1 mês',
		'1_point' => '1 ponto',
		'1_question' => '1 pergunta',
		'1_second' => '1 segundo',
		'1_vote' => '1 voto',
		'1_week' => '1 semana',
		'1_year' => '1 ano',
		'all_categories' => 'Todas as categorias',
		'anonymous' => 'anônimo',
		'answered' => 'respondida',
		'asked' => 'perguntado',
		'by_x' => 'por ^',
		'cancel_button' => 'Cancelar',
		'commented' => 'Comentado',
		'field_required' => 'Por favor, não deixe o campo em branco',
		'general_error' => 'Ocorreu um erro no servidor - Por favor tente novamente.',
		'highest_users' => 'Usuários com mais pontos',
		'in_category_x' => 'em ^',
		'ip_address_x' => 'Endereço IP ^',
		'logged_in_x' => 'Olá ^',
		'max_length_x' => 'Tamanho máximo de ^ caracteres',
		'me' => 'eu',
		'meta_order' => '^what^when^where^who', // sets order of elements like: <answered> <15 hours ago> <in Problems> <by me (500 points)>
		'min_length_x' => 'Por favor forneça mais informação (pelo menos ^ caracteres)',
		'nav_account' => 'Minha conta',
		'nav_activity' => 'Todas atividades',
		'nav_admin' => 'Admin',
		'nav_ask' => 'Faça uma pergunta',
		'nav_feedback' => 'Envie sua opinião',
		'nav_home' => 'Home',
		'nav_login' => 'Login',
		'nav_logout' => 'Logout',
		'nav_qa' => 'Q&A',
		'nav_qs' => 'Perguntas',
		'nav_register' => 'Registro',
		'nav_tags' => 'Tags',
		'nav_unanswered' => 'Sem respostas',
		'nav_users' => 'Usuários',
		'no_active_users' => 'Não foram encontrados usuários ativos',
		'no_answers_found' => 'Não foram encontradas respostas',
		'no_answers_in_x' => 'Nenhuma resposta em ^',
		'no_category' => 'Nenhuma categoria',
		'no_comments_found' => 'Não foram encontrados comentários',
		'no_comments_in_x' => 'Nenhum comentário em ^',
		'no_posts_from_x' => 'Nenhum post de ^',
		'no_questions_found_in_x' => 'Nenhuma questão encontrada em ^',
		'no_questions_found' => 'Não foram encontradas perguntas',
		'no_related_qs_title' => 'Nenhuma questão relacionada',
		'no_results_for_x' => 'Nenhum resultado para ^',
		'no_tags_found' => 'Nenhuma tag encontrada',
		'no_una_questions_found' => 'Não foi encontrada nenhuma pergunta sem resposta',
		'no_una_questions_in_x' => 'Não foi encontrada nenhuma pergunta sem resposta em ^',
		'page_label' => 'Página:',
		'page_next' => 'próximo',
		'page_not_found' => 'Página não encontrada',
		'page_prev' => 'anterior',
		'popular_tags' => 'Tags mais populares',
		'questions_tagged_x' => 'Perguntas recentes tagged ^',
		'recent_activity_in_x' => 'Perguntas, respostas e comentários recentes em ^',
		'recent_activity_title' => 'Perguntas, respostas e comentários recentes',
		'recent_as_in_x' => 'Perguntas respondidas recentemente em ^',
		'recent_as_title' => 'Perguntas respondidas recentemente',
		'recent_cs_in_x' => 'Comentários adicionados recentemente em ^',
		'recent_cs_title' => 'Comentários adicionados recentemente',
		'recent_qs_as_in_x' => 'Perguntas e respostas recentes em ^',
		'recent_qs_as_title' => 'Perguntas e respostas recentes',
		'recent_qs_in_x' => 'Perguntas recentes em ^',
		'recent_qs_title' => 'Perguntas recentes',
		'related_qs_title' => 'Perguntas relacionadas',
		'results_for_x' => 'Resultado da busca ^',
		'save_button' => 'Salvar alterações',
		'search_button' => 'Pesquisar',
		'search_title' => 'Pesquisar Pergunta',
		'send_button' => 'Enviar',
		'suggest_ask' => 'Participe ^1fazendo uma pergunta^2.',
		'suggest_category_qs' => 'Clique para ver todas as ^1perguntas nesta categoria^2.',
		'suggest_qs_tags' => 'Para ver mais clique na ^1lista completa de questões^2 ou ^3nas tags populares^4.',
		'suggest_qs' => 'Clique para ver a ^1lista completa de perguntas^2.',
		'unanswered_qs_in_x' => 'Perguntas recentes sem respostas em ^',
		'unanswered_qs_title' => 'Perguntas recentes sem respostas',
		'vote_disabled_hidden_a' => 'Você não pode votar em respostas ocultas',
		'vote_disabled_hidden_q' => 'Você não pode votar em perguntas ocultas',
		'vote_disabled_q_page_only' => 'Por favor, para votar veja a pergunta',
		'vote_disabled_my_a' => 'Você não pode votar em suas próprias respostas',
		'vote_disabled_my_q' => 'Você não pode votar em suas próprias perguntas',
		'vote_down_popup' => 'Clique para votar contra',
		'vote_limit' => 'Muitos votos recebidos - Por favor tente mais tarde',
		'vote_must_confirm' => 'Por favor ^5confirme seu endereço de email^6 para votar.',
		'vote_must_login' => 'Por favor ^1faça o login^2 ou ^3registre-se^4 para votar.',
		'vote_not_allowed' => 'Não é permitido votar nisto',
		'vote_up_popup' => 'Clique para votar',
		'voted_down_popup' => 'Você votou contra - clique para remover o voto',
		'voted_up_popup' => 'Você votou a favor - clique para remover o voto',
		'x_ago' => '^ atrás',
		'x_answers' => '^ respostas',
		'x_days' => '^ dias',
		'x_disliked' => '^ contra',
		'x_hours' => '^ horas',
		'x_liked' => '^ a favor',
		'x_minutes' => '^ minutos',
		'x_months' => '^ meses',
		'x_points' => '^ pontos',
		'x_questions' => '^ perguntas',
		'x_seconds' => '^ segundos',
		'x_votes' => '^ votos',
		'x_weeks' => '^ semanas',
		'x_years' => '^ anos',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
